@@ -675,51 +675,45 @@ Sequence::reset_row_number()
     @param eval Use this as the constraint expression evaluator.
     @param ce_eval If True, evaluate any CE, otherwise do not.
 */
-bool
-Sequence::read_row(int row, DDS &dds,
-                   ConstraintEvaluator &eval, bool ce_eval)
+bool Sequence::read_row(int row, DDS &dds, ConstraintEvaluator &eval, bool ce_eval)
 {
-    DBG2(cerr << "Entering Sequence::read_row for " << name() << endl);
-    if (row < d_row_number)
-        throw InternalErr("Trying to back up inside a sequence!");
+	DBG2(cerr << "Entering Sequence::read_row for " << name() << endl);
+	if (row < d_row_number) throw InternalErr("Trying to back up inside a sequence!");
 
-    DBG2(cerr << "read_row: row number " << row
-              << ", current row " << d_row_number << endl);
-    if (row == d_row_number)
-    {
-	DBG2(cerr << "Leaving Sequence::read_row for " << name() << endl);
-        return true;
-    }
+	DBG2(cerr << "read_row: row number " << row << ", current row " << d_row_number << endl);
+	if (row == d_row_number) {
+		DBG2(cerr << "Leaving Sequence::read_row for " << name() << endl);
+		return false;
+	}
 
-    dds.timeout_on();
+	dds.timeout_on();
 
-    int eof = 0;  // Start out assuming EOF is false.
-    while (!eof && d_row_number < row) {
-        if (!read_p()) {
-            eof = (read() == false);
-        }
+	bool eof = false;  // Start out assuming EOF is false.
+	while (!eof && d_row_number < row) {
+		if (!read_p()) {
+			// jhrg original version from 10/9/13 : eof = (read() == false);
+			eof = read();
+		}
 
-        // Advance the row number if ce_eval is false (we're not supposed to
-        // evaluate the selection) or both ce_eval and the selection are
-        // true.
-        if (!eof && (!ce_eval || eval.eval_selection(dds, dataset())))
-            d_row_number++;
+		// Advance the row number if ce_eval is false (we're not supposed to
+		// evaluate the selection) or both ce_eval and the selection are
+		// true.
+		if (!eof && (!ce_eval || eval.eval_selection(dds, dataset()))) d_row_number++;
 
-        set_read_p(false); // ...so that the next instance will be read
-    }
+		set_read_p(false); // ...so that the next instance will be read
+	}
 
-    // Once we finish the above loop, set read_p to true so that the caller
-    // knows that data *has* been read. This is how the read() methods of the
-    // elements of the sequence know to not call read() but instead look for
-    // data values inside themselves.
-    set_read_p(true);
+	// Once we finish the above loop, set read_p to true so that the caller
+	// knows that data *has* been read. This is how the read() methods of the
+	// elements of the sequence know to not call read() but instead look for
+	// data values inside themselves.
+	set_read_p(true);
 
-    dds.timeout_off();
+	dds.timeout_off();
 
-    // Return true if we have valid data, false if we've read to the EOF.
-    DBG2(cerr << "Leaving Sequence::read_row for " << name()
-              << " with " << (eof == 0) << endl);
-    return eof == 0;
+	// Return true if we have valid data, false if we've read to the EOF.
+	DBG2(cerr << "Leaving Sequence::read_row for " << name() << " with eof: " << eof << endl);
+	return !eof; // jhrg 10/10/13 was: eof == 0;
 }
 
 // Private. This is used to process constraints on the rows of a sequence.
@@ -1004,7 +998,7 @@ Sequence::intern_data(ConstraintEvaluator &eval, DDS &dds)
     DBG2(cerr << "    intern_data, values: " << &d_values << endl);
 
     // Why use a stack instead of return values? We need the stack because
-    // Sequences neted three of more levels deep will loose the middle
+    // Sequences nested three of more levels deep will loose the middle
     // instances when the intern_data_parent_part_two() code is run.
     sequence_values_stack_t sequence_values_stack;
 
