@@ -50,12 +50,18 @@
 #include "DDS.h"
 
 #include "GNURegex.h"
+#include "GetOpt.h"
 #include "util.h"
 #include "debug.h"
 
 #include "testFile.h"
 #include "test_config.h"
 
+static bool debug = false;
+
+#undef DBG
+#define DBG(x) do { if (debug) (x); } while(false);
+
 using namespace CppUnit;
 using namespace std;
 
@@ -101,15 +107,15 @@ public:
     // DAS, it will need to specialize the BaseType::transfer_attributes()
     // method.
     CPPUNIT_TEST_SUITE( DDSTest );
-#if 1
-        CPPUNIT_TEST(transfer_attributes_test_1);
+
+    CPPUNIT_TEST(transfer_attributes_test_1);
         CPPUNIT_TEST(transfer_attributes_test_2);
 
         CPPUNIT_TEST(symbol_name_test);
-#endif
+
         // These test both transfer_attributes() and print_xml()
         CPPUNIT_TEST(print_xml_test);
-#if 1
+
         CPPUNIT_TEST(print_xml_test2);
         CPPUNIT_TEST(print_xml_test3);
 
@@ -128,9 +134,9 @@ public:
         CPPUNIT_TEST(get_response_size_test_c);
         CPPUNIT_TEST(get_response_size_test_c2);
         CPPUNIT_TEST(get_response_size_test_c3);
-        CPPUNIT_TEST(get_response_size_test_seq);
+
+        // see comment in code below. jhrg 2/4/14 CPPUNIT_TEST(get_response_size_test_seq);
         CPPUNIT_TEST(get_response_size_test_seq_c);
-#endif
 
     CPPUNIT_TEST_SUITE_END();
 
@@ -268,7 +274,7 @@ public:
 
         dds2->transfer_attributes(&das);
 
-        DBG(AttrTable &at2 = dds2->var("c%20d")->get_attr_table()); DBG(at2.print(stderr));
+        DBG( dds2->var("c%20d")->get_attr_table().print(stderr) );
 
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
@@ -292,7 +298,7 @@ public:
             CPPUNIT_FAIL("Error exception");
         }
 
-        DBG(AttrTable &at2 = dds2->var("huh")->get_attr_table()); DBG(at2.print(stderr));
+        DBG(dds2->var("huh")->get_attr_table().print(stderr));
 
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
@@ -318,7 +324,7 @@ public:
             CPPUNIT_FAIL("Error exception");
         }
 
-        DBG(AttrTable &at2 = dds2->var("huh")->get_attr_table()); DBG(at2.print(stderr));
+        DBG(dds2->var("huh")->get_attr_table().print(stderr));
 
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
@@ -361,7 +367,7 @@ public:
             CPPUNIT_FAIL("Error exception");
         }
 
-        DBG(AttrTable &at2 = dds2->var("huh")->get_attr_table()); DBG(at2.print(stderr));
+        DBG(dds2->var("huh")->get_attr_table().print(stderr));
 
         ostringstream oss;
         dds2->print_xml_writer(oss, false, "http://localhost/dods/test.xyz");
@@ -443,30 +449,38 @@ public:
         CPPUNIT_ASSERT(dds2->get_request_size(true) == 17288);
     }
 
+#if 0
+    // This test includes a DAP String and the current implementation of Str::width(bool)
+    // returns sizeof(std::string) which I'm not sure is what it should be doing. Return to
+    // this and decide if it should be returning *string or ...? jhrg 2/4/14
+    // FIXME
     void get_response_size_test_seq() {
         ConstraintEvaluator eval;
         dds2->parse((string) TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.dds");
         eval.parse_constraint("NSCAT%20Rev%2020.NSCAT%20L2", *dds2);
         DBG(cerr << "S2000415.HDF response size: " << dds2->get_request_size(true) << endl);
         DBG(dds2->print_constrained(cerr));
-        CPPUNIT_ASSERT(dds2->get_request_size(true) == 16
-                || dds2->get_request_size(true) == 12);
+        CPPUNIT_ASSERT(dds2->get_request_size(true) == 16 || dds2->get_request_size(true) == 12);
         // sizeof(string) == 8 or 4 depending on the compiler version (?)
     }
+#endif
 
     void get_response_size_test_seq_c() {
         ConstraintEvaluator eval;
         dds2->parse((string) TEST_SRC_DIR + "/dds-testsuite/S2000415.HDF.dds");
         eval.parse_constraint("NSCAT%20Rev%2020.NSCAT%20L2.Low_Wind_Speed_Flag", *dds2);
         DBG(cerr << "S2000415.HDF response size: " << dds2->get_request_size(true) << endl);
+        DBG(dds2->print_constrained(cerr));
         CPPUNIT_ASSERT(dds2->get_request_size(true) == 4);
     }
 
 };
+
 CPPUNIT_TEST_SUITE_REGISTRATION(DDSTest);
 
 }
 
+#if 0
 int main(int, char *[]) {
     CppUnit::TextTestRunner runner;
     runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
@@ -475,4 +489,37 @@ int main(int, char *[]) {
 
     return wasSuccessful ? 0 : 1;
 }
+#endif
 
+int main(int argc, char*argv[]) {
+    CppUnit::TextTestRunner runner;
+    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
+
+    GetOpt getopt(argc, argv, "d");
+    char option_char;
+    while ((option_char = getopt()) != EOF)
+        switch (option_char) {
+        case 'd':
+            debug = 1;  // debug is a static global
+            break;
+        default:
+            break;
+        }
+
+    bool wasSuccessful = true;
+    string test = "";
+    int i = getopt.optind;
+    if (i == argc) {
+        // run them all
+        wasSuccessful = runner.run("");
+    }
+    else {
+        while (i < argc) {
+            test = string("libdap::DDSTest::") + argv[i++];
+
+            wasSuccessful = wasSuccessful && runner.run(test);
+        }
+    }
+
+    return wasSuccessful ? 0 : 1;
+}
