@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 #include <cppunit/TextTestRunner.h>
 #include <cppunit/extensions/TestFactoryRegistry.h>
 #include <cppunit/extensions/HelperMacros.h>
@@ -41,8 +41,14 @@
 #include "../tests/TestStr.h"
 
 #include "GNURegex.h"
+#include "GetOpt.h"
 #include "debug.h"
 
+static bool debug = false;
+
+#undef DBG
+#define DBG(x) do { if (debug) (x); } while(false);
+
 using namespace CppUnit;
 using namespace std;
 
@@ -58,7 +64,7 @@ static const char *s_as_string = \
           _read_p: 0\n\
           _send_p: 0\n\
           _synthesized_p: 0\n\
-          d_parent: 0\n\
+          d_parent: 0.*\n\
           d_attr: 0x.*\n\
 BaseType \\(0x.*\\):\n\
           _name: i1\n\
@@ -103,32 +109,32 @@ public:
     SequenceTest() {}
     ~SequenceTest() {}
 
-    void setUp() { 
+    void setUp() {
 	// Set up a simple sequence. Used to test ctor, assigment, et cetera.
 	s = new TestSequence("s");
 	s->add_var(new TestInt32("i1"));
 	s->add_var(new TestStr("str1"));
 	s->add_var(new TestInt32("i2"));
-        s->set_series_values(true);        
+        s->set_series_values(true);
 
         // Set ss, a two level sequence
         ss = new TestSequence("ss");
         ss->add_var(new TestInt32("i1"));
         ss->set_series_values(true);
-        
+
         ps = new TestSequence("child_of_ss");
         ps->add_var(new TestInt32("i2"));
         ps->set_series_values(true);
-        
+
         ss->add_var(ps);
-        
+
 	// Set up sss, used to test multi-level sequences
 	sss = new TestSequence("sss");
 	sss->add_var(new TestInt32("i1"));
-	
+
 	ts = new TestSequence("child_of_sss");
 	ts->add_var(new TestStr("str1"));
-	
+
 	tts = new TestSequence("child_of_child_of_sss");
 	tts->add_var(new TestInt32("i2"));
 	ts->add_var(tts);
@@ -136,28 +142,28 @@ public:
 	sss->add_var(ts);	// This has to be here because add_var adds
 				// copies of its argument.
         sss->set_series_values(true);
-        
+
         TestTypeFactory ttf;
         dds = new DDS(&ttf);
         dds->add_var(s);
         dds->add_var(ss);
         dds->add_var(sss);
-    } 
+    }
 
-    void tearDown() { 
+    void tearDown() {
 	delete s; s = 0;
         delete ss; ss = 0;
         delete ps; ps = 0;
 	delete sss; sss = 0;
 	delete ts; ts = 0;
 	delete tts; tts = 0;
-        
+
         delete dds; dds = 0;
     }
 
     bool re_match(Regex &r, const char *s) {
 	int match_position = r.match(s, strlen(s));
-	DBG(cerr << "match position: " << match_position 
+	DBG(cerr << "match position: " << match_position
 	    << " string length: " << (int)strlen(s) << endl);
 	return match_position == (int)strlen(s);
     }
@@ -179,6 +185,7 @@ public:
 
     CPPUNIT_TEST_SUITE_END();
 
+#if 0
     // Tests for methods
     void intern_data_test1() {
         ConstraintEvaluator ce;
@@ -186,7 +193,7 @@ public:
         s->set_leaf_sequence();
         try {
             s->intern_data(ce, *dds);
-            
+
             // Test the first value in the first four rows
             BaseType *btp = s->var_value(0, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32);
@@ -203,7 +210,7 @@ public:
             CPPUNIT_ASSERT(!"Error in transfer_data_for_leaf_test1()");
         }
     }
-    
+
     void intern_data_test2() {
         ConstraintEvaluator ce;
         ss->set_send_p(true);
@@ -211,7 +218,7 @@ public:
         try {
             ss->intern_data(ce, *dds);
             DBG(ss->print_val(stdout));
-            
+
             // Test the first value in the first four rows
             BaseType *btp = ss->var_value(0, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32);
@@ -221,7 +228,7 @@ public:
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32768);
             btp = ss->var_value(3, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 1048576);
-            
+
             // Look at some values in the inner sequence
             Sequence *sp = dynamic_cast<Sequence*>(ss->var_value(0, 1));
             CPPUNIT_ASSERT(sp);
@@ -233,7 +240,7 @@ public:
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32768);
             btp = sp->var_value(3, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 1048576);
-            
+
             sp = dynamic_cast<Sequence*>(ss->var_value(3, 1));
             CPPUNIT_ASSERT(sp);
             btp = sp->var_value(0, 0);
@@ -250,7 +257,7 @@ public:
             CPPUNIT_ASSERT(!"Error in transfer_data_test2()");
         }
     }
-    
+
     void intern_data_test3() {
         ConstraintEvaluator ce;
         sss->set_send_p(true);
@@ -267,14 +274,14 @@ public:
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32768);
             btp = sss->var_value(3, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 1048576);
-            
+
             // Look at some values in the inner-most sequence (skip the middle
             // sequence since I don't have a value() accessor for that yet.
             Sequence *sp = dynamic_cast<Sequence*>(sss->var_value(0, 1));
             CPPUNIT_ASSERT(sp);
             Sequence *ssp = dynamic_cast<Sequence*>(sp->var_value(0, 1));
             CPPUNIT_ASSERT(ssp);
-            
+
             btp = ssp->var_value(0, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32);
             btp = ssp->var_value(1, 0);
@@ -283,12 +290,12 @@ public:
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32768);
             btp = ssp->var_value(3, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 1048576);
-            
+
             sp = dynamic_cast<Sequence*>(sss->var_value(3, 1));
             CPPUNIT_ASSERT(sp);
             ssp = dynamic_cast<Sequence*>(sp->var_value(3, 1));
             CPPUNIT_ASSERT(ssp);
-            
+
             btp = ssp->var_value(0, 0);
             CPPUNIT_ASSERT(btp && dynamic_cast<Int32&>(*btp).value() == 32);
             btp = ssp->var_value(1, 0);
@@ -303,7 +310,7 @@ public:
             CPPUNIT_ASSERT(!"Error in transfer_data_test3()");
         }
     }
-    
+
     void intern_data_for_leaf_test() {
         ConstraintEvaluator ce;
         s->set_send_p(true);
@@ -311,7 +318,7 @@ public:
             Sequence::sequence_values_stack_t sequence_values_stack;
             sequence_values_stack.push(&s->d_values);
             s->intern_data_for_leaf(*dds, ce, sequence_values_stack);
-            
+
             // Test the first value in the first four rows
             BaseType *btp = s->var_value(0, 0);
             CPPUNIT_ASSERT(dynamic_cast<Int32&>(*btp).value() == 32);
@@ -328,7 +335,7 @@ public:
             CPPUNIT_ASSERT(!"Error in transfer_data_for_leaf_test()");
         }
     }
-    
+
     void test_set_leaf_sequence3() {
         // Test for the rejection of a Sequence with two sequences in it.
         sss->add_var(ss);
@@ -356,7 +363,7 @@ public:
         sss->set_leaf_sequence(1);
 
         CPPUNIT_ASSERT(!sss->is_leaf_sequence());
-        
+
         i = sss->var_begin();
         inner = dynamic_cast<Sequence*>(*++i);
         CPPUNIT_ASSERT(inner && inner->is_leaf_sequence());
@@ -371,7 +378,7 @@ public:
         s->set_send_p(true);
         s->set_leaf_sequence(1);
         CPPUNIT_ASSERT(s->is_leaf_sequence());
-        
+
         // Two level sequence
         ss->set_send_p(true);
         ss->set_leaf_sequence(1);
@@ -380,12 +387,12 @@ public:
         Sequence::Vars_iter i = ss->var_begin();
         Sequence *inner = dynamic_cast<Sequence*>(*++i);
         CPPUNIT_ASSERT(inner->type() == dods_sequence_c && inner->is_leaf_sequence());
-        
+
         // Three level sequence
         sss->set_send_p(true);
         sss->set_leaf_sequence(1);
         CPPUNIT_ASSERT(!sss->is_leaf_sequence());
-        
+
         i = sss->var_begin();
         inner = dynamic_cast<Sequence*>(*++i);
         CPPUNIT_ASSERT(inner && !inner->is_leaf_sequence());
@@ -394,35 +401,61 @@ public:
         Sequence *inner2 = dynamic_cast<Sequence*>(*++i);
         CPPUNIT_ASSERT(inner2 && inner2->is_leaf_sequence());
     }
-    
-    void ctor_test() {
-	DBG(cerr << "s: " << s->toString() << endl);
-	CPPUNIT_ASSERT(re_match(s_regex, s->toString().c_str()));
-    }
+#endif
 
-    void assignment() {
-	Sequence ts2 = *s;
-	DBG(cerr << "ts2: " << ts2.toString() << endl);
-	CPPUNIT_ASSERT(re_match(s_regex, ts2.toString().c_str()));
-    }
+    void ctor_test()
+	{
+		DBG(cerr << "s: " << s->toString() << endl);
+		CPPUNIT_ASSERT(re_match(s_regex, s->toString().c_str()));
+	}
 
-    void copy_ctor() {
-	Sequence s2 = *s;
-	CPPUNIT_ASSERT(re_match(s_regex, s2.toString().c_str()));
-    }
+	void assignment()
+	{
+		Sequence ts2 = *s;
+		DBG(cerr << "ts2: " << ts2.toString() << endl);
+		CPPUNIT_ASSERT(re_match(s_regex, ts2.toString().c_str()));
+	}
+
+	void copy_ctor()
+	{
+		Sequence s2 = *s;
+		CPPUNIT_ASSERT(re_match(s_regex, s2.toString().c_str()));
+	}
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(SequenceTest);
 
 }
 
-int 
-main( int, char** )
-{
+int main(int argc, char*argv[]) {
     CppUnit::TextTestRunner runner;
-    runner.addTest( CppUnit::TestFactoryRegistry::getRegistry().makeTest() );
+    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
 
-    bool wasSuccessful = runner.run( "", false ) ;
+    GetOpt getopt(argc, argv, "d");
+    char option_char;
+    while ((option_char = getopt()) != EOF)
+        switch (option_char) {
+        case 'd':
+            debug = 1;  // debug is a static global
+            break;
+        default:
+            break;
+        }
+
+    bool wasSuccessful = true;
+    string test = "";
+    int i = getopt.optind;
+    if (i == argc) {
+        // run them all
+        wasSuccessful = runner.run("");
+    }
+    else {
+        while (i < argc) {
+            test = string("libdap::SequenceTest::") + argv[i++];
+
+            wasSuccessful = wasSuccessful && runner.run(test);
+        }
+    }
 
     return wasSuccessful ? 0 : 1;
 }
